<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="en_GB">
<context>
    <name>CBoatElementWidget</name>
    <message>
        <location filename="../boatdef-panel.cpp" line="137"/>
        <source>Sail information</source>
        <translation type="obsolete">Information des Segels</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="145"/>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="146"/>
        <source>name</source>
        <translation>Bezeichnung</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="147"/>
        <source>Reload</source>
        <translation>neu laden</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="148"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="149"/>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="144"/>
        <source>Element information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFileIO</name>
    <message>
        <location filename="" line="0"/>
        <source>Open</source>
        <translation type="obsolete">Öffnen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Save</source>
        <translation type="obsolete">Speichern</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <location filename="../filewriter.h" line="129"/>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="129"/>
        <source>There was an error writing to the selected file.</source>
        <translation>Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="66"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="88"/>
        <source>There was an error reading from the selected file.</source>
        <translation>Beim Lesen aus der gewählten Datei ist ein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="105"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>CFormBoat</name>
    <message>
        <location filename="../formboat.cpp" line="104"/>
        <source>boat</source>
        <translation>Boot</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="105"/>
        <source>&amp;Add</source>
        <translation>&amp;beitragen</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="106"/>
        <source>file</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="167"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <location filename="../formhelp.cpp" line="68"/>
        <source>Sailcut CAD Handbook</source>
        <translation>Sailcut CAD Handbuch</translation>
    </message>
</context>
<context>
    <name>CFormHull</name>
    <message>
        <location filename="../formhull.cpp" line="57"/>
        <source>hull</source>
        <translation>Rumpf</translation>
    </message>
    <message>
        <location filename="../formhull.cpp" line="58"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Abmessungen</translation>
    </message>
</context>
<context>
    <name>CFormHullDefBase</name>
    <message>
        <location filename="../formhulldefbase.ui" line="20"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="42"/>
        <source>Deck and bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="60"/>
        <source>Planking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="72"/>
        <source>Automatic planking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="123"/>
        <source>lower plank angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="187"/>
        <source>top plank angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="194"/>
        <source>Number of planks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="212"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="269"/>
        <source>Bottom sweep angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="290"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="402"/>
        <source>Max Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="611"/>
        <source>Forward shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="618"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="633"/>
        <source>Forward height </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="640"/>
        <source>Max Width position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="662"/>
        <source>Stem angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="669"/>
        <source>Transom angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1639"/>
        <source>Aft height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="691"/>
        <source>Aft width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="698"/>
        <source>Aft shape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="760"/>
        <source>Hull name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="770"/>
        <source>Deck</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1646"/>
        <source>Forward height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="891"/>
        <source>Plank 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1618"/>
        <source>Chine angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1625"/>
        <source>Sweep angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1632"/>
        <source>Plank angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1034"/>
        <source>Plank 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1177"/>
        <source>Plank 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1320"/>
        <source>Plank 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1463"/>
        <source>Plank 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1606"/>
        <source>Plank 6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1774"/>
        <source>Check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1781"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1788"/>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1817"/>
        <source>Dimensions are in millimeters and angles in degrees measured from horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="879"/>
        <source>Planks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="395"/>
        <source>txt_BBW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="423"/>
        <source>txt_BfwdHeight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="444"/>
        <source>txt_BLWL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="465"/>
        <source>txt_BaftW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="559"/>
        <source>txt_BaftHeight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="604"/>
        <source>Dead rise angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="745"/>
        <source>txt_HullID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="826"/>
        <source>txt_DaftHeight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="847"/>
        <source>txt_DfwdHeight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="861"/>
        <source>Side angle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <location filename="" line="0"/>
        <source>to &amp;DXF</source>
        <translation type="obsolete">&amp;DXF</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>to &amp;TXT sail</source>
        <translation type="obsolete">&amp;TXT Segel</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>to &amp;XML sail</source>
        <translation type="obsolete">&amp;XML Segel</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="131"/>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="136"/>
        <source>&amp;Open</source>
        <translation>Ö&amp;ffnen</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="138"/>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="139"/>
        <source>Save &amp;As</source>
        <translation>Speichern &amp;unter</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="141"/>
        <source>&amp;Quit</source>
        <translation>Be&amp;enden</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Dimensions</source>
        <translation type="obsolete">&amp;Abmessungen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Mould</source>
        <translation type="obsolete">&amp;Form</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Patches</source>
        <translation type="obsolete">&amp;Verstärkungen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Rig</source>
        <translation type="obsolete">&amp;Rigg</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="129"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="144"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="155"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="334"/>
        <source>About Sailcut CAD</source>
        <translation>Über Sailcut CAD</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="157"/>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="158"/>
        <source>About &amp;Sailcut CAD</source>
        <translation>Über &amp;Sailcut CAD</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="145"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="137"/>
        <source>Open &amp;recent</source>
        <translation>Zuletzt geöffnete P&amp;rojekte</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>E&amp;xport 3D sail</source>
        <translation type="obsolete">E&amp;xport 3D-Segel</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>to &amp;Carlson plotter</source>
        <translation type="obsolete">&amp;Carlson Plotter</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="156"/>
        <source>Sailcut CAD &amp;Handbook</source>
        <translation>Sailcut CAD &amp;Handbuch</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>shaded view</source>
        <translation type="obsolete">schattierte Ansicht</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>wireframe view</source>
        <translation type="obsolete">Ansicht als Drahtmodell</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>development</source>
        <translation type="obsolete">Entwicklung</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>created new sail</source>
        <translation type="obsolete">neu erstelltes Segel</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="215"/>
        <source>loaded &apos;%1&apos;</source>
        <translation>geladen &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="220"/>
        <source>error loading &apos;%1&apos;</source>
        <translation>Fehler beim Laden von &apos;%1&apos; </translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="504"/>
        <source>wrote &apos;%1&apos;</source>
        <translation>gespeichert &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>There was a data printing error</source>
        <translation type="obsolete">Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>There was a development printing error</source>
        <translation type="obsolete">Fehler beim Drucken der Entwicklungsansicht</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>There was a drawing printing error</source>
        <translation type="obsolete">Fehler beim drucken der Zeichnung</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>data</source>
        <translation type="obsolete">Daten</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>drawing</source>
        <translation type="obsolete">Zeichnung</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Print</source>
        <translation type="obsolete">Dr&amp;ucken</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Sail type</source>
        <translation type="obsolete">Segeltyp</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Mainsail</source>
        <translation type="obsolete">Großsegel</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Jib</source>
        <translation type="obsolete">Fock</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Sail layout</source>
        <translation type="obsolete">Segelschnitt</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Cross Cut</source>
        <translation type="obsolete">Kreuzschnitt</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Horizontalschnitt</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Radial Cut</source>
        <translation type="obsolete">Radialschnitt</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Twist-Foot Schnitt</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Vertical Cut</source>
        <translation type="obsolete">Vertikalschnitt</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Mitre Cut</source>
        <translation type="obsolete">Gehrungsschnitt</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source> sections,   </source>
        <translation type="obsolete"> Segmente,   </translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Rig </source>
        <translation type="obsolete">Rigg </translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Boat LOA</source>
        <translation type="obsolete">Bootslänge LüA</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Höhe I des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Basis J des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Tack position X</source>
        <translation type="obsolete">Segelhalsposition X</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Tack height Y</source>
        <translation type="obsolete">Segelhalshöhe Y</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Sail dimensions</source>
        <translation type="obsolete">Segelabmessungen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Luff length</source>
        <translation type="obsolete">Länge des Vorlieks</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Gaffelwinkel relativ zum Vorliek</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Gaff length</source>
        <translation type="obsolete">Länge der Gaffel</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Foot length</source>
        <translation type="obsolete">Länge des Unterlieks</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Leech length</source>
        <translation type="obsolete">Länge des Achterlieks</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Luff round</source>
        <translation type="obsolete">Vorliek-Bogen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Gaff round</source>
        <translation type="obsolete">Gaffel-Bogen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Leech round</source>
        <translation type="obsolete">Achterliek-Bogen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Foot round</source>
        <translation type="obsolete">Unterliek-Bogen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Luff round position</source>
        <translation type="obsolete">Position des Vorliekbogens</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Gaff round position</source>
        <translation type="obsolete">Position des Gaffelbogens</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Leech round position</source>
        <translation type="obsolete">Position des Achterliekbogens</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Foot round position</source>
        <translation type="obsolete">Position des Unterliekbogens</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Sail settings</source>
        <translation type="obsolete">Eigenschaften des Segels</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Twist angle</source>
        <translation type="obsolete">Verwindungswinkel</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Sheeting angle</source>
        <translation type="obsolete">Winkel der Segelbahn</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Bahnennähte und Säume</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Cloth width</source>
        <translation type="obsolete">Bahnbreite</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Seams width</source>
        <translation type="obsolete">Nahtbreite</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Leech hem width</source>
        <translation type="obsolete">Breite des Achterlieksaumes</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Other hem width</source>
        <translation type="obsolete">andere Saumbreiten</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Sail mould</source>
        <translation type="obsolete">Segelform</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Luff factor</source>
        <translation type="obsolete">Vorliegsfaktor</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Depth</source>
        <translation type="obsolete">Tiefe</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Leech factor</source>
        <translation type="obsolete">Achterlieksfaktor</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Top profile</source>
        <translation type="obsolete">Oberes Profil</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Mittleres Profil bei Höhe h =</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Bottom profile</source>
        <translation type="obsolete">Unteres Profil</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Neigung der Mastspur</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source> head gores,   </source>
        <translation type="obsolete">Radialkeile im Kopfabschnitt </translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Wing</source>
        <translation type="obsolete">Tragfläche</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source> luff gores.</source>
        <translation type="obsolete">Radialkeile beginnend am Kopf und endend am Segelhals.</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>deg</source>
        <translation type="obsolete">°</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Export &amp;development</source>
        <translation type="obsolete">Export &amp;Entwicklung</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>to &amp;Hand-plotting format</source>
        <translation type="obsolete">ins &amp;Hand-Plotterformat </translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="132"/>
        <source>sail</source>
        <translation>Segel</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="133"/>
        <source>hull</source>
        <translation>Rumpf</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="134"/>
        <source>rig</source>
        <translation>Rigg </translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="135"/>
        <source>boat</source>
        <translation>Boot</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="148"/>
        <source>&amp;Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="149"/>
        <source>&amp;Close</source>
        <translation>Be&amp;enden</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="150"/>
        <source>Close &amp;All</source>
        <translation>Beenden &amp;alles</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="151"/>
        <source>&amp;Tile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="152"/>
        <source>&amp;Cascade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="207"/>
        <source>unknown document type &apos;%1&apos;</source>
        <translation>Fehler document type %1</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="461"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <location filename="../formmould.cpp" line="60"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="66"/>
        <source>Vertical repartition</source>
        <translation>Senkrechte Teilung</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="42"/>
        <source>Sail mould</source>
        <translation>Segelform</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Help</source>
        <translation type="obsolete">&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="56"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="77"/>
        <source>Top profile</source>
        <translation>Oberes Profil</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="78"/>
        <source>Middle profile</source>
        <translation>Mittleres Profil</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="79"/>
        <source>Bottom profile</source>
        <translation>Unteres Profil</translation>
    </message>
</context>
<context>
    <name>CFormPanelGroup</name>
    <message>
        <location filename="../formpanelgroup.cpp" line="56"/>
        <source>panels</source>
        <translation>Tafeln</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <location filename="" line="0"/>
        <source>Rig</source>
        <translation type="obsolete">Rigg </translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;New</source>
        <translation type="obsolete">&amp;Neu</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>sail &amp;definition</source>
        <translation type="obsolete">&amp;Definition des Segels</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>3D &amp;sail</source>
        <translation type="obsolete">3D &amp;Segel</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Add sail</source>
        <translation type="obsolete">neues Segel &amp;hinzufügen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Open</source>
        <translation type="obsolete">Ö&amp;ffnen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Open &amp;recent</source>
        <translation type="obsolete">zuletzt geöffnete P&amp;rojekte</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Save</source>
        <translation type="obsolete">&amp;Speichern</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Save &amp;As</source>
        <translation type="obsolete">Speichern &amp;unter</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;Close</source>
        <translation type="obsolete">Be&amp;enden</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>&amp;File</source>
        <translation type="obsolete">&amp;Datei</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="59"/>
        <source>rig</source>
        <translation>Rigg </translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="60"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Abmessungen</translation>
    </message>
</context>
<context>
    <name>CFormRigDefBase</name>
    <message>
        <location filename="../formrigdefbase.ui" line="20"/>
        <source>Rig dimensions</source>
        <translation>Riggabmessungen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="53"/>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="68"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="75"/>
        <source>Spreaders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="122"/>
        <source>= SPNB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="129"/>
        <source>Number of spreaders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="147"/>
        <source>Spreader height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="173"/>
        <source>txt_SPH2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="197"/>
        <source>txt_SPH1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="221"/>
        <source>txt_SPH3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="231"/>
        <source>SPH2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="238"/>
        <source>SPH3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="245"/>
        <source>SPH1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="255"/>
        <source>Spreader length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="267"/>
        <source>SPW3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="280"/>
        <source>txt_SPW3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="290"/>
        <source>SPW1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="303"/>
        <source>txt_SPW1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="313"/>
        <source>SPW2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="326"/>
        <source>txt_SPW2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="350"/>
        <source>Shrouds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="376"/>
        <source>Cap shroud base width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="397"/>
        <source>= CSH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="418"/>
        <source>Lower shroud base width </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="439"/>
        <source>txt_LSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="463"/>
        <source>txt_CSH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="487"/>
        <source>= CSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="508"/>
        <source>Cap shroud height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="529"/>
        <source>txt_CSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="553"/>
        <source>= LSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="587"/>
        <source>Fore triangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="626"/>
        <source>txt_foreI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="636"/>
        <source>= I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="657"/>
        <source>txt_foreJ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="667"/>
        <source>= J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="674"/>
        <source>Fore triangle base</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="681"/>
        <source>Fore triangle hoist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="691"/>
        <source>Mast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="703"/>
        <source>Mast width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="710"/>
        <source>= MW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="723"/>
        <source>txt_MW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="739"/>
        <source>txt_MC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="749"/>
        <source>= MC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="756"/>
        <source>Mast cord</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="766"/>
        <source>lbl_MRkD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="776"/>
        <source>= MRkD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="783"/>
        <source>Mast rake angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="804"/>
        <source>txt_MH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="814"/>
        <source>txt_MRnd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="840"/>
        <source>Mast rake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="847"/>
        <source>= MRkM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="868"/>
        <source>txt_MRkM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="892"/>
        <source>Mast height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="899"/>
        <source>= MH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="906"/>
        <source>= MRnd</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="927"/>
        <source>Mast round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="934"/>
        <source>= MRndPos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="955"/>
        <source>Mast round position </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1015"/>
        <source>Mainsail</source>
        <translation>Großsegel</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1044"/>
        <source>lbl_MS_LuffRP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1068"/>
        <source>@ </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1095"/>
        <source>lbl_MS_LuffR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1122"/>
        <source>lbl_MS_TackY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1146"/>
        <source>Y =</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1173"/>
        <source>lbl_MS_TackX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1191"/>
        <source>X =</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1209"/>
        <source>Tack</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1249"/>
        <source>lbl_MS_LuffL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1267"/>
        <source>= MSL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1288"/>
        <source>Luff length </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1309"/>
        <source>Luff round</source>
        <translation>Vorliek-Bogen</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1333"/>
        <source>lbl_MS_Rake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1351"/>
        <source>= MSR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1372"/>
        <source>Luff rake</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1409"/>
        <source>Tack height </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1430"/>
        <source>txt_BAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1454"/>
        <source>= BAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1476"/>
        <source>Head height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1491"/>
        <source>= HAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1512"/>
        <source>txt_HAD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1538"/>
        <source>Check</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1572"/>
        <source>All dimensions are in millimeter and angles in degrees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1602"/>
        <source>Rig ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1618"/>
        <source>Description of rig</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormSail</name>
    <message>
        <location filename="../formsail.cpp" line="73"/>
        <source>sail</source>
        <translation>Segel</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="76"/>
        <source>&amp;Print</source>
        <translation>Dr&amp;ucken</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="77"/>
        <source>data</source>
        <translation>Daten</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="78"/>
        <source>drawing</source>
        <translation>Zeichnung</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="106"/>
        <source>development</source>
        <translation>Entwicklung</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="82"/>
        <source>E&amp;xport 3D sail</source>
        <translation>E&amp;xport 3D-Segel</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="93"/>
        <source>to &amp;DXF</source>
        <translation>&amp;DXF</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="96"/>
        <source>to &amp;TXT sail</source>
        <translation>&amp;TXT Segel</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="97"/>
        <source>to &amp;XML sail</source>
        <translation>&amp;XML Segel</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="91"/>
        <source>Export &amp;development</source>
        <translation>Export &amp;Entwicklung</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="92"/>
        <source>to &amp;Carlson plotter</source>
        <translation>&amp;Carlson Plotter</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="95"/>
        <source>to &amp;Hand-plotting format</source>
        <translation>ins &amp;Hand-Plotterformat </translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="100"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Abmessungen</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="101"/>
        <source>&amp;Mould</source>
        <translation>&amp;Form</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="102"/>
        <source>&amp;Patches</source>
        <translation>&amp;Verstärkungen</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="393"/>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="336"/>
        <source>There was a data printing error</source>
        <translation>Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="365"/>
        <source>There was a development printing error</source>
        <translation>Fehler beim Drucken der Entwicklungsansicht</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="393"/>
        <source>There was a drawing printing error</source>
        <translation>Fehler beim drucken der Zeichnung</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="85"/>
        <source>to &amp;SVG</source>
        <translation>&amp;SVG</translation>
    </message>
</context>
<context>
    <name>CFormSailDef</name>
    <message>
        <location filename="../formsaildef.cpp" line="1090"/>
        <source>Sail corners coordinates</source>
        <translation>Eckpunktkoordinaten des Segels</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1091"/>
        <source>tack</source>
        <translation>Segelhals</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1092"/>
        <source>clew</source>
        <translation>Schothorn</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1093"/>
        <source>head</source>
        <translation>Kopf</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1094"/>
        <source>peak</source>
        <translation>Nock</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>IRC width measurements</source>
        <translation type="obsolete">IRC - Breite</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1099"/>
        <source>Sail width measurements </source>
        <translation>Segel breite</translation>
    </message>
</context>
<context>
    <name>CFormSailDefBase</name>
    <message>
        <location filename="../formsaildefbase.ui" line="19"/>
        <source>Sail definition</source>
        <translation>Definition des Segels</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="315"/>
        <source>Sail dimensions</source>
        <translation>Segelabmessungen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="793"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="448"/>
        <source>Round position</source>
        <translation>Position des Bogens</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="406"/>
        <source>Luff length</source>
        <translation>Länge des Vorlieks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="413"/>
        <source>Foot length</source>
        <translation>Länge des Unterlieks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="427"/>
        <source>Leech length</source>
        <translation>Länge des Achterlieks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="455"/>
        <source>Gaff length</source>
        <translation>Länge der Gaffel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="462"/>
        <source>Leech round</source>
        <translation>Achterliek-Bogen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="578"/>
        <source>Gaff round</source>
        <translation>Gaffel-Bogen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="469"/>
        <source>Luff round</source>
        <translation>Vorliek-Bogen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="476"/>
        <source>Foot round</source>
        <translation>Unterliek-Bogen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="870"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="940"/>
        <source>deg</source>
        <translation>°</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="585"/>
        <source>Gaff angle from luff</source>
        <translation>Gaffelwinkel relativ zum Vorliek</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="69"/>
        <source>Rig geometry</source>
        <translation>Geometrie der Takelage</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="271"/>
        <source>Fore triangle base  J</source>
        <translation>Basis J des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="285"/>
        <source>Tack height</source>
        <translation>Segelhalshöhe</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="264"/>
        <source>Distance tack to stem</source>
        <translation>Abstand zwischen Segelhals und Vorsteven</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="229"/>
        <source>Main sail</source>
        <translation>Großsegel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="119"/>
        <source>Jib</source>
        <translation>Fock</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="292"/>
        <source>Fore triangle hoist  I</source>
        <translation>Höhe I des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="257"/>
        <source>Boat length LOA</source>
        <translation>Bootslänge LüA</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="278"/>
        <source>Mast / Luff rake</source>
        <translation>Neigung der Mastspur</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="725"/>
        <source>Cloth</source>
        <translation>Material</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="800"/>
        <source>Seam width</source>
        <translation>Nahtbreite</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="765"/>
        <source>Cloth width</source>
        <translation>Bahnbreite</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="950"/>
        <source>Layout</source>
        <translation>Schnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="962"/>
        <source>Mitre cut</source>
        <translation>Gehrungsschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="969"/>
        <source>Cross cut</source>
        <translation>Kreuzschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="976"/>
        <source>Twist foot</source>
        <translation>Twist-Foot Schnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1045"/>
        <source>Horizontal cut</source>
        <translation>Horizontalschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1010"/>
        <source>Number of sections</source>
        <translation>Anzahl der Segmente</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1031"/>
        <source>Number of radial gores</source>
        <translation>Anzahl der Radialkeile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="990"/>
        <source>Radial cut</source>
        <translation>Radialschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="983"/>
        <source>Vertical cut</source>
        <translation>Vertikalschnitt</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="824"/>
        <source>Sail shape</source>
        <translation>Segelform</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="884"/>
        <source>Top depth</source>
        <translation>Obere Segeltiefe</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="891"/>
        <source>Mid depth</source>
        <translation>Mittlere Segeltiefe</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="898"/>
        <source>Foot depth</source>
        <translation>Untere Segeltiefe</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="919"/>
        <source>Twist angle</source>
        <translation>Verwindungswinkel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1074"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="702"/>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="779"/>
        <source>Leech hem</source>
        <translation>Achterlieksaum</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="786"/>
        <source>Other hems</source>
        <translation>Andere Säume</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="926"/>
        <source>Sheeting angle</source>
        <translation>Winkel der Segelbahn</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="" line="0"/>
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="669"/>
        <source>Sail area</source>
        <translation>Segelfläche</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="662"/>
        <source>Diagonal</source>
        <translation>Diagonale</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1081"/>
        <source>Compute</source>
        <translation>Berechnen</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="56"/>
        <source>Sail ID</source>
        <translation>Segel ID</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1038"/>
        <source>Number of luff gores</source>
        <translation>Anzahl der Radialkeile beginnend am Kopf und endend am Segelhals</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="98"/>
        <source>Dihedral angle</source>
        <translation>Öffnungswinkel</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="105"/>
        <source>Wing</source>
        <translation>Tragfläche</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="31"/>
        <source>Sail identifier</source>
        <translation>Segelnummer</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="692"/>
        <source>m2</source>
        <translation>m2</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <location filename="" line="0"/>
        <source>Sail information</source>
        <translation type="obsolete">Information des Segels</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>file</source>
        <translation type="obsolete">Datei</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>name</source>
        <translation type="obsolete">Bezeichnung</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Reload</source>
        <translation type="obsolete">neu laden</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Remove</source>
        <translation type="obsolete">Entfernen</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>Update</source>
        <translation type="obsolete">Aktualisieren</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Beim Lesen aus der gewählten Datei ist ein Fehler aufgetreten.</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <location filename="" line="0"/>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">Dieses System hat keine OpenGL Unterstützung.</translation>
    </message>
</context>
<context>
    <name>CSailPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="152"/>
        <source>Sailcut CAD data sheet</source>
        <translation>Sailcut CAD Datenblatt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="158"/>
        <source>Mainsail</source>
        <translation>Großsegel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="161"/>
        <source>Jib</source>
        <translation>Fock</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="164"/>
        <source>Wing</source>
        <translation>Tragfläche</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="164"/>
        <source>deg</source>
        <translation>°</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="167"/>
        <source>Sail type</source>
        <translation>Segeltyp</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="173"/>
        <source>Cross Cut</source>
        <translation>Kreuzschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="176"/>
        <source>Horizontal Cut</source>
        <translation>Horizontalschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="179"/>
        <source>Radial Cut</source>
        <translation>Radialschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="180"/>
        <source>sections</source>
        <translation> Segmente </translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="181"/>
        <source>head gores</source>
        <translation>Radialkeile im Kopfabschnitt </translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="182"/>
        <source>luff gores</source>
        <translation>Radialkeile beginnend am Kopf und endend am Segelhals</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="185"/>
        <source>Twist Foot Cut</source>
        <translation>Twist-Foot Schnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="188"/>
        <source>Vertical Cut</source>
        <translation>Vertikalschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="191"/>
        <source>Mitre Cut</source>
        <translation>Gehrungsschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="194"/>
        <source>Sail layout</source>
        <translation>Segelschnitt</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="197"/>
        <source>Rig</source>
        <translation>Rigg </translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="198"/>
        <source>Boat LOA</source>
        <translation>Bootslänge LüA</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="199"/>
        <source>Mast/Luff rake</source>
        <translation>Neigung der Mastspur</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="200"/>
        <source>Tack position X</source>
        <translation>Segelhalsposition X</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="201"/>
        <source>Tack height Y</source>
        <translation>Segelhalshöhe Y</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="202"/>
        <source>Fore triangle hoist I</source>
        <translation>Höhe I des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="203"/>
        <source>Fore triangle base J</source>
        <translation>Basis J des Vorsegeldreiecks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="206"/>
        <source>Sail dimensions</source>
        <translation>Segelabmessungen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="207"/>
        <source>Luff length</source>
        <translation>Länge des Vorlieks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="208"/>
        <source>Foot length</source>
        <translation>Länge des Unterlieks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="209"/>
        <source>Leech length</source>
        <translation>Länge des Achterlieks</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="210"/>
        <source>Gaff length</source>
        <translation>Länge der Gaffel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="211"/>
        <source>Gaff angle wrt luff</source>
        <translation>Gaffelwinkel relativ zum Vorliek</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="214"/>
        <source>Shape of edges</source>
        <translation>Gestalt von Rändern</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="215"/>
        <source>Luff round</source>
        <translation>Vorliek-Bogen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="216"/>
        <source>Luff round position</source>
        <translation>Position des Vorliekbogens</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="217"/>
        <source>Foot round</source>
        <translation>Unterliek-Bogen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="218"/>
        <source>Foot round position</source>
        <translation>Position des Unterliekbogens</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="219"/>
        <source>Leech round</source>
        <translation>Achterliek-Bogen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="220"/>
        <source>Leech round position</source>
        <translation>Position des Achterliekbogens</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="221"/>
        <source>Gaff round</source>
        <translation>Gaffel-Bogen</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="222"/>
        <source>Gaff round position</source>
        <translation>Position des Gaffelbogens</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="225"/>
        <source>Sail settings</source>
        <translation>Eigenschaften des Segels</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="226"/>
        <source>Twist angle</source>
        <translation>Verwindungswinkel</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="227"/>
        <source>Sheeting angle</source>
        <translation>Winkel der Segelbahn</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="230"/>
        <source>Cloth seams and hems</source>
        <translation>Bahnennähte und Säume</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="231"/>
        <source>Cloth width</source>
        <translation>Bahnbreite</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="232"/>
        <source>Seams width</source>
        <translation>Nahtbreite</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="233"/>
        <source>Leech hem width</source>
        <translation>Breite des Achterlieksaumes</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="234"/>
        <source>Other hem width</source>
        <translation>andere Saumbreiten</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="237"/>
        <source>Sail mould</source>
        <translation>Segelform</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="238"/>
        <source>Luff factor</source>
        <translation>Vorliegsfaktor</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="238"/>
        <source>Depth</source>
        <translation>Tiefe</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="238"/>
        <source>Leech factor</source>
        <translation>Achterlieksfaktor</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="240"/>
        <source>Top profile</source>
        <translation>Oberes Profil</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="246"/>
        <source>Mid profile at h = </source>
        <translation>Mittleres Profil bei Höhe h =</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="252"/>
        <source>Bottom profile</source>
        <translation>Unteres Profil</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <location filename="../sailviewer-panel.cpp" line="137"/>
        <source>Display parameters</source>
        <translation>Anzeigeparameter</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="138"/>
        <source>elevation</source>
        <translation>vertikal</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="139"/>
        <source>azimuth</source>
        <translation>horizontal</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="141"/>
        <source>Controls</source>
        <translation>Darstellung</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="142"/>
        <source>Reset view</source>
        <translation>Ansicht zurücksetzen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="145"/>
        <source>Labeling</source>
        <translation>Segelzeichen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="147"/>
        <source>Zoom in</source>
        <translation>Einzoomen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="148"/>
        <source>Zoom out</source>
        <translation>Auszoomen</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="186"/>
        <source>deg</source>
        <translation>°</translation>
    </message>
</context>
<context>
    <name>CSailViewerTabs</name>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="64"/>
        <source>shaded view</source>
        <translation>schattierte Ansicht</translation>
    </message>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="66"/>
        <source>wireframe view</source>
        <translation>Ansicht als Drahtmodell</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <location filename="../widgetprofile.cpp" line="242"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="240"/>
        <source>Luff shape</source>
        <translation>Vorliekform</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="241"/>
        <source>Depth</source>
        <translation>Tiefe</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="243"/>
        <source>Leech shape</source>
        <translation>Achterliekform</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="247"/>
        <source>degrees</source>
        <translation>°</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="246"/>
        <source>cord</source>
        <translation>Schnur</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <location filename="" line="0"/>
        <source>error</source>
        <translation type="obsolete">Fehler</translation>
    </message>
    <message>
        <location filename="" line="0"/>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Beim Lesen aus der gewählten Datei ist ein Fehler aufgetreten.</translation>
    </message>
</context>
</TS>
